# This puppet manifest is used to configure Sweden Connect "test my eid" servers
# https://github.com/swedenconnect/docker-test-my-eid

# @param environment          The environment that the server belongs to. (referenced in compose file)
# @param version              Version of the docker image to use. (referenced in compose file)
# @param service_name         The name of the service, ex test.test.swedenconnect.se (referenced in compose file)
# @param server_fqdn          The FQDN of the server. (referenced in compose file)
# @param service_dir          The directory where all app related config and files are stored. (referenced in compose file)
class eid::test_my_eid (
  Enum['test', 'qa', 'prod'] $environment,
  String                     $version,
  String                     $service_name = '',
  String                     $server_fqdn = $facts['networking']['fqdn'],
  String                     $service_dir = '/opt/test-my-eid',
) {

  if $version {

    # Allow HTTP/HTTPS from load balancer servers
    $lb_ips = hiera_array("lb_${environment}_servers",[])
    sunet::nftables::allow { 'allow-http-from-lbs':
      from => $lb_ips,
      port => 80,
    }
    sunet::nftables::allow { 'allow-https-from-lbs':
      from => $lb_ips,
      port => 443,
    }

    # Create the environment specific config files from template
    file { "${service_dir}/application-${environment}.yml":
      ensure  => 'file',
      content => template("eid/test_my_eid/application-${environment}.yml.erb")
    }
    file { "${service_dir}/idp-disco-${environment}.yml":
      ensure  => 'file',
      content => template("eid/test_my_eid/idp-disco-${environment}.yml.erb")
    }

    sunet::docker_compose { 'test-my-eid':
      content          => template('eid/test_my_eid/docker-compose.yml.erb'),
      service_name     => 'test-my-eid',
      compose_dir      => '/opt/',
      compose_filename => 'docker-compose.yml',
      description      => 'Test My eID'
    }
  }
}
